@@ -4,16 +4,14 @@ Main interface for qldb service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_qldb import (
         Client,
         QLDBClient,
     )
 
-    session = boto3.Session()
-
-    client: QLDBClient = boto3.client("qldb")
-    session_client: QLDBClient = session.client("qldb")
+    session = Session()
+    client: QLDBClient = session.client("qldb")
     ```
 """
 from .client import QLDBClient
