@@ -28,7 +28,9 @@ __all__ = (
     "PermissionsModeType",
     "S3ObjectEncryptionTypeType",
     "StreamStatusType",
+    "QLDBServiceName",
     "ServiceName",
+    "ResourceServiceName",
 )
 
 
@@ -40,6 +42,7 @@ OutputFormatType = Literal["ION_BINARY", "ION_TEXT", "JSON"]
 PermissionsModeType = Literal["ALLOW_ALL", "STANDARD"]
 S3ObjectEncryptionTypeType = Literal["NO_ENCRYPTION", "SSE_KMS", "SSE_S3"]
 StreamStatusType = Literal["ACTIVE", "CANCELED", "COMPLETED", "FAILED", "IMPAIRED"]
+QLDBServiceName = Literal["qldb"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -71,6 +74,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -193,6 +197,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -341,3 +346,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
