@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence, Union
 
+from typing_extensions import NotRequired
+
 from .literals import (
     EncryptionStatusType,
     ErrorCauseType,
@@ -97,29 +99,16 @@ CancelJournalKinesisStreamResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateLedgerRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateLedgerRequestRequestTypeDef",
+CreateLedgerRequestRequestTypeDef = TypedDict(
+    "CreateLedgerRequestRequestTypeDef",
     {
         "Name": str,
         "PermissionsMode": PermissionsModeType,
+        "Tags": NotRequired[Mapping[str, str]],
+        "DeletionProtection": NotRequired[bool],
+        "KmsKey": NotRequired[str],
     },
 )
-_OptionalCreateLedgerRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateLedgerRequestRequestTypeDef",
-    {
-        "Tags": Mapping[str, str],
-        "DeletionProtection": bool,
-        "KmsKey": str,
-    },
-    total=False,
-)
-
-
-class CreateLedgerRequestRequestTypeDef(
-    _RequiredCreateLedgerRequestRequestTypeDef, _OptionalCreateLedgerRequestRequestTypeDef
-):
-    pass
-
 
 CreateLedgerResponseTypeDef = TypedDict(
     "CreateLedgerResponseTypeDef",
@@ -195,30 +184,17 @@ DescribeLedgerResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredExportJournalToS3RequestRequestTypeDef = TypedDict(
-    "_RequiredExportJournalToS3RequestRequestTypeDef",
+ExportJournalToS3RequestRequestTypeDef = TypedDict(
+    "ExportJournalToS3RequestRequestTypeDef",
     {
         "Name": str,
         "InclusiveStartTime": Union[datetime, str],
         "ExclusiveEndTime": Union[datetime, str],
         "S3ExportConfiguration": "S3ExportConfigurationTypeDef",
         "RoleArn": str,
+        "OutputFormat": NotRequired[OutputFormatType],
     },
 )
-_OptionalExportJournalToS3RequestRequestTypeDef = TypedDict(
-    "_OptionalExportJournalToS3RequestRequestTypeDef",
-    {
-        "OutputFormat": OutputFormatType,
-    },
-    total=False,
-)
-
-
-class ExportJournalToS3RequestRequestTypeDef(
-    _RequiredExportJournalToS3RequestRequestTypeDef, _OptionalExportJournalToS3RequestRequestTypeDef
-):
-    pass
-
 
 ExportJournalToS3ResponseTypeDef = TypedDict(
     "ExportJournalToS3ResponseTypeDef",
@@ -228,27 +204,14 @@ ExportJournalToS3ResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetBlockRequestRequestTypeDef = TypedDict(
-    "_RequiredGetBlockRequestRequestTypeDef",
+GetBlockRequestRequestTypeDef = TypedDict(
+    "GetBlockRequestRequestTypeDef",
     {
         "Name": str,
         "BlockAddress": "ValueHolderTypeDef",
+        "DigestTipAddress": NotRequired["ValueHolderTypeDef"],
     },
 )
-_OptionalGetBlockRequestRequestTypeDef = TypedDict(
-    "_OptionalGetBlockRequestRequestTypeDef",
-    {
-        "DigestTipAddress": "ValueHolderTypeDef",
-    },
-    total=False,
-)
-
-
-class GetBlockRequestRequestTypeDef(
-    _RequiredGetBlockRequestRequestTypeDef, _OptionalGetBlockRequestRequestTypeDef
-):
-    pass
-
 
 GetBlockResponseTypeDef = TypedDict(
     "GetBlockResponseTypeDef",
@@ -275,28 +238,15 @@ GetDigestResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetRevisionRequestRequestTypeDef = TypedDict(
-    "_RequiredGetRevisionRequestRequestTypeDef",
+GetRevisionRequestRequestTypeDef = TypedDict(
+    "GetRevisionRequestRequestTypeDef",
     {
         "Name": str,
         "BlockAddress": "ValueHolderTypeDef",
         "DocumentId": str,
+        "DigestTipAddress": NotRequired["ValueHolderTypeDef"],
     },
 )
-_OptionalGetRevisionRequestRequestTypeDef = TypedDict(
-    "_OptionalGetRevisionRequestRequestTypeDef",
-    {
-        "DigestTipAddress": "ValueHolderTypeDef",
-    },
-    total=False,
-)
-
-
-class GetRevisionRequestRequestTypeDef(
-    _RequiredGetRevisionRequestRequestTypeDef, _OptionalGetRevisionRequestRequestTypeDef
-):
-    pass
-
 
 GetRevisionResponseTypeDef = TypedDict(
     "GetRevisionResponseTypeDef",
@@ -307,8 +257,8 @@ GetRevisionResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredJournalKinesisStreamDescriptionTypeDef = TypedDict(
-    "_RequiredJournalKinesisStreamDescriptionTypeDef",
+JournalKinesisStreamDescriptionTypeDef = TypedDict(
+    "JournalKinesisStreamDescriptionTypeDef",
     {
         "LedgerName": str,
         "RoleArn": str,
@@ -316,29 +266,16 @@ _RequiredJournalKinesisStreamDescriptionTypeDef = TypedDict(
         "Status": StreamStatusType,
         "KinesisConfiguration": "KinesisConfigurationTypeDef",
         "StreamName": str,
+        "CreationTime": NotRequired[datetime],
+        "InclusiveStartTime": NotRequired[datetime],
+        "ExclusiveEndTime": NotRequired[datetime],
+        "Arn": NotRequired[str],
+        "ErrorCause": NotRequired[ErrorCauseType],
     },
 )
-_OptionalJournalKinesisStreamDescriptionTypeDef = TypedDict(
-    "_OptionalJournalKinesisStreamDescriptionTypeDef",
-    {
-        "CreationTime": datetime,
-        "InclusiveStartTime": datetime,
-        "ExclusiveEndTime": datetime,
-        "Arn": str,
-        "ErrorCause": ErrorCauseType,
-    },
-    total=False,
-)
 
-
-class JournalKinesisStreamDescriptionTypeDef(
-    _RequiredJournalKinesisStreamDescriptionTypeDef, _OptionalJournalKinesisStreamDescriptionTypeDef
-):
-    pass
-
-
-_RequiredJournalS3ExportDescriptionTypeDef = TypedDict(
-    "_RequiredJournalS3ExportDescriptionTypeDef",
+JournalS3ExportDescriptionTypeDef = TypedDict(
+    "JournalS3ExportDescriptionTypeDef",
     {
         "LedgerName": str,
         "ExportId": str,
@@ -348,98 +285,44 @@ _RequiredJournalS3ExportDescriptionTypeDef = TypedDict(
         "ExclusiveEndTime": datetime,
         "S3ExportConfiguration": "S3ExportConfigurationTypeDef",
         "RoleArn": str,
+        "OutputFormat": NotRequired[OutputFormatType],
     },
 )
-_OptionalJournalS3ExportDescriptionTypeDef = TypedDict(
-    "_OptionalJournalS3ExportDescriptionTypeDef",
-    {
-        "OutputFormat": OutputFormatType,
-    },
-    total=False,
-)
 
-
-class JournalS3ExportDescriptionTypeDef(
-    _RequiredJournalS3ExportDescriptionTypeDef, _OptionalJournalS3ExportDescriptionTypeDef
-):
-    pass
-
-
-_RequiredKinesisConfigurationTypeDef = TypedDict(
-    "_RequiredKinesisConfigurationTypeDef",
+KinesisConfigurationTypeDef = TypedDict(
+    "KinesisConfigurationTypeDef",
     {
         "StreamArn": str,
+        "AggregationEnabled": NotRequired[bool],
     },
 )
-_OptionalKinesisConfigurationTypeDef = TypedDict(
-    "_OptionalKinesisConfigurationTypeDef",
-    {
-        "AggregationEnabled": bool,
-    },
-    total=False,
-)
 
-
-class KinesisConfigurationTypeDef(
-    _RequiredKinesisConfigurationTypeDef, _OptionalKinesisConfigurationTypeDef
-):
-    pass
-
-
-_RequiredLedgerEncryptionDescriptionTypeDef = TypedDict(
-    "_RequiredLedgerEncryptionDescriptionTypeDef",
+LedgerEncryptionDescriptionTypeDef = TypedDict(
+    "LedgerEncryptionDescriptionTypeDef",
     {
         "KmsKeyArn": str,
         "EncryptionStatus": EncryptionStatusType,
+        "InaccessibleKmsKeyDateTime": NotRequired[datetime],
     },
 )
-_OptionalLedgerEncryptionDescriptionTypeDef = TypedDict(
-    "_OptionalLedgerEncryptionDescriptionTypeDef",
-    {
-        "InaccessibleKmsKeyDateTime": datetime,
-    },
-    total=False,
-)
-
-
-class LedgerEncryptionDescriptionTypeDef(
-    _RequiredLedgerEncryptionDescriptionTypeDef, _OptionalLedgerEncryptionDescriptionTypeDef
-):
-    pass
-
 
 LedgerSummaryTypeDef = TypedDict(
     "LedgerSummaryTypeDef",
     {
-        "Name": str,
-        "State": LedgerStateType,
-        "CreationDateTime": datetime,
+        "Name": NotRequired[str],
+        "State": NotRequired[LedgerStateType],
+        "CreationDateTime": NotRequired[datetime],
     },
-    total=False,
 )
 
-_RequiredListJournalKinesisStreamsForLedgerRequestRequestTypeDef = TypedDict(
-    "_RequiredListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
+ListJournalKinesisStreamsForLedgerRequestRequestTypeDef = TypedDict(
+    "ListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
     {
         "LedgerName": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListJournalKinesisStreamsForLedgerRequestRequestTypeDef = TypedDict(
-    "_OptionalListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListJournalKinesisStreamsForLedgerRequestRequestTypeDef(
-    _RequiredListJournalKinesisStreamsForLedgerRequestRequestTypeDef,
-    _OptionalListJournalKinesisStreamsForLedgerRequestRequestTypeDef,
-):
-    pass
-
 
 ListJournalKinesisStreamsForLedgerResponseTypeDef = TypedDict(
     "ListJournalKinesisStreamsForLedgerResponseTypeDef",
@@ -450,28 +333,14 @@ ListJournalKinesisStreamsForLedgerResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListJournalS3ExportsForLedgerRequestRequestTypeDef = TypedDict(
-    "_RequiredListJournalS3ExportsForLedgerRequestRequestTypeDef",
+ListJournalS3ExportsForLedgerRequestRequestTypeDef = TypedDict(
+    "ListJournalS3ExportsForLedgerRequestRequestTypeDef",
     {
         "Name": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListJournalS3ExportsForLedgerRequestRequestTypeDef = TypedDict(
-    "_OptionalListJournalS3ExportsForLedgerRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListJournalS3ExportsForLedgerRequestRequestTypeDef(
-    _RequiredListJournalS3ExportsForLedgerRequestRequestTypeDef,
-    _OptionalListJournalS3ExportsForLedgerRequestRequestTypeDef,
-):
-    pass
-
 
 ListJournalS3ExportsForLedgerResponseTypeDef = TypedDict(
     "ListJournalS3ExportsForLedgerResponseTypeDef",
@@ -485,10 +354,9 @@ ListJournalS3ExportsForLedgerResponseTypeDef = TypedDict(
 ListJournalS3ExportsRequestRequestTypeDef = TypedDict(
     "ListJournalS3ExportsRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListJournalS3ExportsResponseTypeDef = TypedDict(
@@ -503,10 +371,9 @@ ListJournalS3ExportsResponseTypeDef = TypedDict(
 ListLedgersRequestRequestTypeDef = TypedDict(
     "ListLedgersRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListLedgersResponseTypeDef = TypedDict(
@@ -544,26 +411,13 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredS3EncryptionConfigurationTypeDef = TypedDict(
-    "_RequiredS3EncryptionConfigurationTypeDef",
+S3EncryptionConfigurationTypeDef = TypedDict(
+    "S3EncryptionConfigurationTypeDef",
     {
         "ObjectEncryptionType": S3ObjectEncryptionTypeType,
+        "KmsKeyArn": NotRequired[str],
     },
 )
-_OptionalS3EncryptionConfigurationTypeDef = TypedDict(
-    "_OptionalS3EncryptionConfigurationTypeDef",
-    {
-        "KmsKeyArn": str,
-    },
-    total=False,
-)
-
-
-class S3EncryptionConfigurationTypeDef(
-    _RequiredS3EncryptionConfigurationTypeDef, _OptionalS3EncryptionConfigurationTypeDef
-):
-    pass
-
 
 S3ExportConfigurationTypeDef = TypedDict(
     "S3ExportConfigurationTypeDef",
@@ -574,32 +428,18 @@ S3ExportConfigurationTypeDef = TypedDict(
     },
 )
 
-_RequiredStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
-    "_RequiredStreamJournalToKinesisRequestRequestTypeDef",
+StreamJournalToKinesisRequestRequestTypeDef = TypedDict(
+    "StreamJournalToKinesisRequestRequestTypeDef",
     {
         "LedgerName": str,
         "RoleArn": str,
         "InclusiveStartTime": Union[datetime, str],
         "KinesisConfiguration": "KinesisConfigurationTypeDef",
         "StreamName": str,
+        "Tags": NotRequired[Mapping[str, str]],
+        "ExclusiveEndTime": NotRequired[Union[datetime, str]],
     },
 )
-_OptionalStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
-    "_OptionalStreamJournalToKinesisRequestRequestTypeDef",
-    {
-        "Tags": Mapping[str, str],
-        "ExclusiveEndTime": Union[datetime, str],
-    },
-    total=False,
-)
-
-
-class StreamJournalToKinesisRequestRequestTypeDef(
-    _RequiredStreamJournalToKinesisRequestRequestTypeDef,
-    _OptionalStreamJournalToKinesisRequestRequestTypeDef,
-):
-    pass
-
 
 StreamJournalToKinesisResponseTypeDef = TypedDict(
     "StreamJournalToKinesisResponseTypeDef",
@@ -643,27 +483,14 @@ UpdateLedgerPermissionsModeResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateLedgerRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateLedgerRequestRequestTypeDef",
+UpdateLedgerRequestRequestTypeDef = TypedDict(
+    "UpdateLedgerRequestRequestTypeDef",
     {
         "Name": str,
+        "DeletionProtection": NotRequired[bool],
+        "KmsKey": NotRequired[str],
     },
 )
-_OptionalUpdateLedgerRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateLedgerRequestRequestTypeDef",
-    {
-        "DeletionProtection": bool,
-        "KmsKey": str,
-    },
-    total=False,
-)
-
-
-class UpdateLedgerRequestRequestTypeDef(
-    _RequiredUpdateLedgerRequestRequestTypeDef, _OptionalUpdateLedgerRequestRequestTypeDef
-):
-    pass
-
 
 UpdateLedgerResponseTypeDef = TypedDict(
     "UpdateLedgerResponseTypeDef",
@@ -681,7 +508,6 @@ UpdateLedgerResponseTypeDef = TypedDict(
 ValueHolderTypeDef = TypedDict(
     "ValueHolderTypeDef",
     {
-        "IonText": str,
+        "IonText": NotRequired[str],
     },
-    total=False,
 )
